@@ -177,7 +177,6 @@ attachments."
 
 (defcustom gnorb-gnus-sent-groups nil
   "A list of strings indicating sent mail groups.
-
 In some cases, Gnorb can't detect where your sent messages are
 stored (ie if you're using IMAP sent mail folders instead of
 local archiving. If you want Gnorb to be able to find sent
@@ -187,7 +186,7 @@ server+group combinations, ie \"nnimap+Server:[Gmail]/Sent
 Mail\", or something similar. This only has to be done once for
 each message."
   :group 'gnorb-gnus
-  :type 'list)
+  :type '(repeat (string :tag "Group name")))
 
 (defvar gnorb-gnus-capture-attachments nil
   "Holding place for attachment names during the capture
@@ -502,7 +501,6 @@ work."
        :annotation link))
     (org-capture nil gnorb-gnus-new-todo-capture-key)
     (when msg-id
-      (org-entry-put (point) gnorb-org-msg-id-key msg-id)
       (gnorb-registry-make-entry msg-id sender subject (org-id-get-create) group))))
 
 ;;; If an incoming message should trigger state-change for a Org todo,
@@ -598,7 +596,7 @@ you'll stay in the Gnus summary buffer."
 			(throw 'target (setq targ h)))))
 	    ;; If not, use the refile interface to choose one.
 	    (setq targ (org-refile-get-location
-			"Trigger heading" nil t))
+			"Trigger heading" nil))
 	    (setq targ
 		  (save-window-excursion
 		    (find-file (nth 1 targ))
@@ -894,6 +892,8 @@ HEAD-TEXT, if present, as its name.  Otherwise create an
 ephemeral one, with RET as the value of its quit-config."
   (interactive)
   (require 'nnir)
+  (unless (gnus-alive-p)
+    (gnus))
   (let* ((nnir-address (gnorb-gnus-find-gnorb-server))
 	 (name (if persist
 		   (read-string
